
data {
  int N;         // Sample size (N = 36)
  int N_iid;     // Number of focal animals
  int N_tid;     // Number of trials
  real Time[N];   // Before stimulus presentation = 0, After = 1
  real Group[N]; // Larger group = 0, Smaller group = 1
  real Sex[N];   // Female = 0, Male = 1
  real Diet[N];  // Folivory = 0, Frugivory = 1
  int C_S[N];    // Maximum number of individuals (except infants) in proximity with focal animals
  int IID[N];    // Focal animal ID
  int TID[N];    // Trial ID
  int Gs[N];     // Group size of subject groups (except infants)
}

parameters {
  real a0;
  real a[N_tid];
  real a1[N_iid]; 
  real<lower=0> s_ag;
  real<lower=0> s_a;
  real b;
  real c;
  real d;
  real e;
  real f;
  real g; 
  real h;
  }
  
model {
 //local
  for(j in 1:N_iid){
    a1[j] ~ normal(a0, s_ag);
  }
  
  for (i in 1:N_tid) {
    a[i] ~ normal(a1[IID[i]], s_a);
  }
  
  //global
  for (n in 1:N){
    C_S[n] ~ poisson_log(a[TID[n]] 
                         + b*Time[n]
                         + c*Group[n]
                         + d*Time[n]*Group[n] 
                         + e*Sex[n]
                         + f*Time[n]*Sex[n]
                         + g*Diet[n]
                         + h*Time[n]*Diet[n] 
                         + log(Gs[n]));
  }
  
  //prior
  s_ag ~ student_t(4, 0, 10);
  s_a ~ student_t(4, 0, 10);
}


generated quantities {
  int m_pred[N];
  real log_lik[N];
  
  for (n in 1:N){
    m_pred[n] = poisson_log_rng(a[TID[n]] 
                         + b*Time[n]
                         + c*Group[n]
                         + d*Time[n]*Group[n] 
                         + e*Sex[n]
                         + f*Time[n]*Sex[n]
                         + g*Diet[n]
                         + h*Time[n]*Diet[n] 
                         + log(Gs[n]));
  }
  
  for (n in 1:N){
    log_lik[n] = poisson_log_lpmf(C_S[n] | a[TID[n]] 
                         + b*Time[n]
                         + c*Group[n]
                         + d*Time[n]*Group[n] 
                         + e*Sex[n]
                         + f*Time[n]*Sex[n]
                         + g*Diet[n]
                         + h*Time[n]*Diet[n] 
                         + log(Gs[n]));
    }
}
